bomcheck help 3

# bomcheck help (page 3)

1. How to copy from SolidWorks

1. The Interim BOM Table defined
2. How to copy from an Interim BOM

1. Make sure to exclude inventory items
2. Descriptions cannot be copied to the clipboard
3. If OP number is not 10

2. How to paste into SyteLine

1. Column order MUST match that of the Interim BOM
2. Use Edit > Paste Rows Append

1. Manage popup windows that show warning messages
2. If you mistakenly paste in the wrong Op number

## 1. How to copy from SolidWorks

### 1a. The Interim BOM Table defined

When bomcheck runs it gathers all the CAD BOMs, and from those BOMs generates a new type of BOM called an Interim BOM. An Interim BOM is neither a CAD BOM nor an ERP BOM. It is an intermediate BOM that bomcheck uses to compare to the ERP BOM.

The Interim BOM has a structure exactly like SyteLine's BOMs; that is, columns are arranged the same, lengths are summed and converted to feet, etc.

An Interim BOM appears whenever no matching SyteLine BOM is found to compare it to that in the Interim BOM. Image #1, Interim BOM

### 1b. How to copy from an Interim BOM

From the Interim BOM (see image #1), copy, via Ctrl+C, values you want to paste from columns Op, WC, Item, and Q. It is not necessary to copy Description and U/M values. ERP will fill in its own values for these.

### 1b-i. Make sure to exclude inventory items

Do not add inventory bin stock items to SyteLine BOMs, e.g. carbon steel pipe nipples. (Unless, possibly, you're creating a kit. Non-inventory items fall under SyteLine's product code no. 810.) These part numbers can be made to not show in the Interim BOM. To do this employ the "drop list". (See Section 1 of bomcheck's help.)

### 1b-ii. Descriptions cannot be copied to the clipboard

When you copy from an Interim BOM and you inappropriately include values from the Description column and/or the U column, bomcheckgui will ignore the Description and U values; i.e., they will not be copied to the clipboard. (When data is pasted, SyteLine will insert its own Desription and U/M.)

### 1b-iii. If OP number is not 10

If the Op no. is not 10 for what you will be pasting in, you can enter a different Op number into the Interim BOM. Enter your different number in the Op column next to the assembly number. The remainder of the Op numbers for that assembly will automatically change. Op 15 is shown as an example in image above.

## 2. How to paste into SyteLine

### 2a. Column order MUST match that of the Interim BOM

For a particular item that you wish to create a BOM for, go to Item (enter your item no.) > Current Materials. Then order the columns in SyteLine exactly like those shown in Image #2; i.e., Operation, WC, Material, Quantity, Description, U/M, and Obsolete Date. (Left click on a column header and pick "Edit Grid Columns...")

Image #2, SyteLine BOM

### 2b. Use Edit > Paste Rows Append

After copying from the Interim BOM go to Edit (the pencil icon) > Paste Rows Append. A popup window opens up looking for data that you want pasted. Do Ctrl+P. Once pasted, click Save.

### 2b-i. Manage popup windows that show warning messages

When pasting, if an error message pops up saying Slow Inventory Item, or Part doesn't exist, etc., click whatever button in the popup menu that will allow your paste operation to continue. You can go back later and make corrections once pasting is done. If an item doesn't exist that you inserted, the pn will be flagged and you will be prevented from saving. (Suggestion: Preestablish new subassemblies and new parts before entering items into a top level BOM.)

### 2b-ii. If you mistakenly paste in the wrong Op number

If you mistakenly paste the incorrect Op no., SyteLine's WC value will not be PICK. Instead WC will incorrectly be FAB or PAINT, or some other WC. Please correct your mistake.

If the Op number you try to paste in is not already established, the paste will fail.